# lscealice

LSCE ALICE is a python tkinter interface to align ice core data series.

_this doc file is under construction 👷‍♀️_

## Installation

Depending on your workflow, you can either 

- download and run the jupyter notebook `.ipynb` or python `.py` file. Make sure you have the right dependencies installed.

- You can also install it using [pipx](https://pipx.pypa.io/latest/installation/) with

```
pipx install git+https://github.com/secretpenguin75/lscealice.git
```
then run it directly from your terminal with

```
lscealice
```

- Finally, you can install it in your python distribution using pip

```
pip install lsce alice
```

Then within python run
```
import lscealice
lscealice.startUI()
```

Have fun!🐧
